"""
This is my personal Python package, `pykirill`,
which includes a collection of utilities and functions that I frequently use during scientific exploration.
This package is especially designed to be portable,
making it suitable for environments like Google Colab where setup needs to be minimal
"""

from .version import VERSION as __version__  # noqa: F401
